import request from '@/utils/request'

// 查询群组配置列表
export function listGroupconfig(query) {
  return request({
    url: '/clocking/groupconfig/list',
    method: 'get',
    params: query
  })
}

// 查询机构人员档案列表
export function addUser(data) {
  return request({
    url: '/clocking/groupconfig/addUser',
    method: 'post',
    data: data
  })
}

// 查询群组配置详细
export function getGroupconfig(id) {
  return request({
    url: '/clocking/groupconfig/' + id,
    method: 'get'
  })
}

// 新增群组配置
export function addGroupconfig(data) {
  return request({
    url: '/clocking/groupconfig',
    method: 'post',
    data: data
  })
}

// 修改群组配置
export function updateGroupconfig(data) {
  return request({
    url: '/clocking/groupconfig',
    method: 'put',
    data: data
  })
}

// 删除群组配置
export function delGroupconfig(id) {
  return request({
    url: '/clocking/groupconfig/' + id,
    method: 'delete'
  })
}

// 导出群组配置
export function exportGroupconfig(query) {
  return request({
    url: '/clocking/groupconfig/export',
    method: 'get',
    params: query
  })
}
