<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch">
      <el-form-item label="群组编码" prop="groupCode">
        <el-input
          v-model="queryParams.groupCode"
          placeholder="请输入群组编码"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="群组名称" prop="groupName">
        <el-input
          v-model="queryParams.groupName"
          placeholder="请输入群组名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['clocking:groupconfig:add']"
        >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['clocking:groupconfig:edit']"
        >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['clocking:groupconfig:remove']"
        >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['clocking:groupconfig:export']"
        >导出
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="groupconfigList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <el-table-column label="群组编码" align="center" prop="groupCode"/>
      <el-table-column label="群组名称" align="center" prop="groupName"/>
      <el-table-column label="群组成员" align="center" prop="groupMemberText">
        <template slot-scope="scope">
          <div>
            <el-tag style="margin: 2px;display: inline-block" v-for="item in scope.row.groupMemberText">{{
                item
              }}
            </el-tag>
          </div>
        </template>
      </el-table-column>
      <el-table-column label="备注" align="center" prop="remark"/>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-plus"
            @click="addMembers(scope.row)"
          >添加成员
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['clocking:groupconfig:edit']"
          >修改
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['clocking:groupconfig:remove']"
          >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改群组配置对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules">
        <el-form-item label="群组编码" prop="groupCode">
          <el-input v-model="form.groupCode" placeholder="请输入群组编码"/>
        </el-form-item>
        <el-form-item label="群组名称" prop="groupName">
          <el-input v-model="form.groupName" placeholder="请输入群组名称"/>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入备注"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>


    <el-dialog :title="userListDialog.title" :visible.sync="userListDialog.open" width="800px" append-to-body>
      <el-form :model="userListDialog" ref="queryForm" :inline="true" v-show="showSearch">
        <el-form-item label="姓名" prop="userName">
          <el-input
            v-model="userListDialog.userName"
            placeholder="请输入姓名"
            clearable
            size="small"
            @keyup.enter.native="handleQuery"
          />
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery2">搜索</el-button>
        </el-form-item>
      </el-form>
      <el-row :gutter="10" class="mb8">
        <el-col :span="1.5">
          <el-button
            type="primary"
            plain
            icon="el-icon-plus"
            size="mini"
            @click="addGroupUser"
          >添加
          </el-button>
        </el-col>
        <right-toolbar :showSearch.sync="showSearch" @queryTable="getUserDialogList"></right-toolbar>
      </el-row>
      <el-table v-loading="userListDialog.loading" :data="filesList" @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" align="center"/>
        <el-table-column label="用户编号" align="center" prop="userCode"/>
        <el-table-column label="工号" align="center" prop="jobNo"/>
        <el-table-column label="姓名" align="center" prop="userName"/>
      </el-table>
      <pagination
        v-show="userListDialog.total>0"
        :total="userListDialog.total"
        :page.sync="userListDialog.pageNum"
        :limit.sync="userListDialog.pageSize"
        @pagination="getUserDialogList"
      />
    </el-dialog>


  </div>
</template>

<script>
import {
  listGroupconfig,
  getGroupconfig,
  delGroupconfig,
  addGroupconfig,
  updateGroupconfig,
  exportGroupconfig,
  addUser
} from '@/api/clocking/groupconfig'
import { listFiles } from '@/api/files/files'

export default {
  name: 'Groupconfig',
  data() {
    return {
      userListDialog: {
        open: false,
        title: '人员选择',
        total: 0,
        loading: true,
        pageNum: 1,
        pageSize: 10
      },
      filesList: [],
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 群组配置表格数据
      groupconfigList: [],
      // 弹出层标题
      title: '',
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        groupCode: null,
        groupName: null,
        groupMember: null,
        isDelete: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {},
      hsGroupConfigId: '',
      hsGroupConfig: {}
    }
  },
  created() {
    this.getList()
    this.getUserDialogList()
  },
  methods: {
    addMembers(item) {
      this.userListDialog.open = true
      this.hsGroupConfigId = item.id
    },
    /** 查询机构人员档案列表 */
    getUserDialogList() {
      this.userListDialog.loading = true
      listFiles(this.userListDialog).then(response => {
        this.filesList = response.rows
        this.userListDialog.total = response.total
        this.userListDialog.loading = false
      })
    },
    /** 查询群组配置列表 */
    getList() {
      this.loading = true
      listGroupconfig(this.queryParams).then(response => {
        this.groupconfigList = response.rows
        this.total = response.total
        this.loading = false
      })
    },
    // 取消按钮
    cancel() {
      this.open = false
      this.reset()
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        groupCode: null,
        groupName: null,
        groupMember: null,
        isDelete: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        remark: null
      }
      this.resetForm('form')
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1
      this.getList()
    },
    /** 搜索按钮操作 */
    handleQuery2() {
      this.userListDialog.pageNum = 1
      this.getUserDialogList()
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm('queryForm')
      this.handleQuery()
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.userCode)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 添加用户按钮 */
    addGroupUser() {
      this.hsGroupConfig = {
        id: this.hsGroupConfigId,
        groupMemberText: this.ids
      }
      console.log(this.hsGroupConfig.groupMemberText)
      addUser(this.hsGroupConfig).then(re => {
        if (re.code === 200) {
          this.$modal.msgSuccess('添加成功')
          this.getUserDialogList()
          this.getList()
        }
      })
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset()
      this.open = true
      this.title = '添加群组配置'
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset()
      const id = row.id || this.ids
      getGroupconfig(id).then(response => {
        this.form = response.data
        this.open = true
        this.title = '修改群组配置'
      })
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs['form'].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateGroupconfig(this.form).then(() => {
              this.$modal.msgSuccess('修改成功')
              this.open = false
              this.getList()
            })
          } else {
            addGroupconfig(this.form).then(() => {
              this.$modal.msgSuccess('新增成功')
              this.open = false
              this.getList()
            })
          }
        }
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids
      this.$modal.confirm('是否确认删除群组配置编号为"' + ids + '"的数据项？').then(function() {
        return delGroupconfig(ids)
      }).then(() => {
        this.getList()
        this.$modal.msgSuccess('删除成功')
      }).catch(() => {
      })
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams
      this.$modal.confirm('是否确认导出所有群组配置数据项？').then(() => {
        this.exportLoading = true
        return exportGroupconfig(queryParams)
      }).then(response => {
        this.$download.name(response.msg)
        this.exportLoading = false
      }).catch(() => {
      })
    }
  }
}
</script>
